@@ -23,7 +23,6 @@ import (
 	"github.com/spf13/cobra"
 
 	"github.com/GoogleContainerTools/skaffold/cmd/skaffold/app/tips"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/graph"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/util"
@@ -36,20 +35,13 @@ func NewCmdDeploy() *cobra.Command {
 		WithExample("Build the artifacts and collect the tags into a file", "build --file-output=tags.json").
 		WithExample("Deploy those tags", "deploy --build-artifacts=tags.json").
 		WithExample("Build the artifacts and then deploy them", "build -q | skaffold deploy --build-artifacts -").
-		WithExample("Deploy without first rendering the manifests", "deploy --skip-render").
 		WithCommonFlags().
-		WithFlags([]*Flag{
-			{Value: &opts.SkipRender, Name: "skip-render", DefValue: false, Usage: "Don't render the manifests, just deploy them", IsEnum: true},
-		}).
 		WithHouseKeepingMessages().
 		NoArgs(doDeploy)
 }
 
 func doDeploy(ctx context.Context, out io.Writer) error {
 	return withRunner(ctx, out, func(r runner.Runner, configs []util.VersionedConfig) error {
-		if opts.SkipRender {
-			return r.DeployAndLog(ctx, out, []graph.Artifact{})
-		}
 		var artifacts []*latest.Artifact
 		for _, cfg := range configs {
 			artifacts = append(artifacts, cfg.(*latest.SkaffoldConfig).Build.Artifacts...)
@@ -59,7 +51,11 @@ func doDeploy(ctx context.Context, out io.Writer) error {
 			tips.PrintUseRunVsDeploy(out)
 			return err
 		}
-
-		return r.DeployAndLog(ctx, out, buildArtifacts)
+		// Render
+		manifests, errR := r.Render(ctx, out, buildArtifacts, false)
+		if errR != nil {
+			return errR
+		}
+		return r.DeployAndLog(ctx, out, buildArtifacts, manifests)
 	})
 }
