@@ -216,6 +216,7 @@ func TestFilterWithDebugging(t *testing.T) {
 }
 
 func TestDebugEventsRPC_StatusCheck(t *testing.T) {
+	t.Skipf("Disable the test dues to flakyness. https://github.com/GoogleContainerTools/skaffold/issues/7405")
 	MarkIntegrationTest(t, CanRunWithoutGcp)
 
 	// Run skaffold build first to fail quickly on a build failure
@@ -230,6 +231,7 @@ func TestDebugEventsRPC_StatusCheck(t *testing.T) {
 }
 
 func TestDebugEventsRPC_NoStatusCheck(t *testing.T) {
+	t.Skipf("Disable the test dues to flakyness. https://github.com/GoogleContainerTools/skaffold/issues/7405")
 	MarkIntegrationTest(t, CanRunWithoutGcp)
 
 	// Run skaffold build first to fail quickly on a build failure
@@ -243,6 +245,7 @@ func TestDebugEventsRPC_NoStatusCheck(t *testing.T) {
 	waitForDebugEvent(t, client, rpcAddr)
 }
 
+// nolint add lint back after https://github.com/GoogleContainerTools/skaffold/issues/7405
 func waitForDebugEvent(t *testing.T, client *NSKubernetesClient, rpcAddr string) {
 	client.WaitForPodsReady()
 
