@@ -17,11 +17,9 @@ limitations under the License.
 package deploy
 
 import (
-	"bytes"
 	"context"
 	"io"
 	"strconv"
-	"strings"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/access"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
@@ -59,6 +57,14 @@ func (m DeployerMux) GetDeployers() []Deployer {
 	return m.deployers
 }
 
+func (m DeployerMux) GetDeployersInverse() []Deployer {
+	inverse := m.deployers
+	for i, j := 0, len(inverse)-1; i < j; i, j = i+1, j-1 {
+		inverse[i], inverse[j] = inverse[j], inverse[i]
+	}
+	return inverse
+}
+
 func (m DeployerMux) GetAccessor() access.Accessor {
 	var accessors access.AccessorMux
 	for _, deployer := range m.deployers {
@@ -105,7 +111,11 @@ func (m DeployerMux) RegisterLocalImages(images []graph.Artifact) {
 	}
 }
 
-func (m DeployerMux) Deploy(ctx context.Context, w io.Writer, as []graph.Artifact) error {
+func (m DeployerMux) ConfigName() string {
+	return ""
+}
+
+func (m DeployerMux) Deploy(ctx context.Context, w io.Writer, as []graph.Artifact, l manifest.ManifestListByConfig) error {
 	for i, deployer := range m.deployers {
 		eventV2.DeployInProgress(i)
 		w, ctx = output.WithEventContext(ctx, w, constants.Deploy, strconv.Itoa(i))
@@ -120,7 +130,7 @@ func (m DeployerMux) Deploy(ctx context.Context, w io.Writer, as []graph.Artifac
 				return err
 			}
 		}
-		if err := deployer.Deploy(ctx, w, as); err != nil {
+		if err := deployer.Deploy(ctx, w, as, l); err != nil {
 			eventV2.DeployFailed(i, err)
 			endTrace(instrumentation.TraceEndError(err))
 			return err
@@ -158,13 +168,15 @@ func (m DeployerMux) Dependencies() ([]string, error) {
 	return deps.ToList(), nil
 }
 
-func (m DeployerMux) Cleanup(ctx context.Context, w io.Writer, dryRun bool) error {
-	for _, deployer := range m.deployers {
+func (m DeployerMux) Cleanup(ctx context.Context, w io.Writer, dryRun bool, manifestsByConfig manifest.ManifestListByConfig) error {
+	// Reverse order of deployers for cleanup to ensure resources
+	// are removed before their definitions are removed.
+	for _, deployer := range m.GetDeployersInverse() {
 		ctx, endTrace := instrumentation.StartTrace(ctx, "Cleanup")
 		if dryRun {
 			output.Yellow.Fprintln(w, "Following resources would be deleted:")
 		}
-		if err := deployer.Cleanup(ctx, w, dryRun); err != nil {
+		if err := deployer.Cleanup(ctx, w, dryRun, manifestsByConfig); err != nil {
 			return err
 		}
 		endTrace()
@@ -172,22 +184,5 @@ func (m DeployerMux) Cleanup(ctx context.Context, w io.Writer, dryRun bool) erro
 	return nil
 }
 
-func (m DeployerMux) Render(ctx context.Context, w io.Writer, as []graph.Artifact, offline bool, filepath string) error {
-	resources, buf := []string{}, &bytes.Buffer{}
-	for _, deployer := range m.deployers {
-		ctx, endTrace := instrumentation.StartTrace(ctx, "Render")
-		buf.Reset()
-		if err := deployer.Render(ctx, buf, as, offline, "" /* never write to files */); err != nil {
-			endTrace(instrumentation.TraceEndError(err))
-			return err
-		}
-		resources = append(resources, buf.String())
-		endTrace()
-	}
-
-	allResources := strings.Join(resources, "\n---\n")
-	return manifest.Write(strings.TrimSpace(allResources), filepath, w)
-}
-
 // TrackBuildArtifacts should *only* be called on individual deployers. This is a noop.
 func (m DeployerMux) TrackBuildArtifacts(_ []graph.Artifact) {}
