@@ -43,8 +43,8 @@ func TestEmptyState(t *testing.T) {
 				},
 				Deploy: latest.DeployConfig{
 					DeployType: latest.DeployType{
-						KubectlDeploy: &latest.KubectlDeploy{},
-						HelmDeploy:    &latest.HelmDeploy{Releases: []latest.HelmRelease{{Name: "first"}, {Name: "second"}}},
+						KubectlDeploy:    &latest.KubectlDeploy{},
+						LegacyHelmDeploy: &latest.LegacyHelmDeploy{Releases: []latest.HelmRelease{{Name: "first"}, {Name: "second"}}},
 					},
 				},
 			},
@@ -76,7 +76,7 @@ func TestEmptyState(t *testing.T) {
 				},
 				Deploy: latest.DeployConfig{
 					DeployType: latest.DeployType{
-						KustomizeDeploy: &latest.KustomizeDeploy{},
+						KubectlDeploy: &latest.KubectlDeploy{},
 					},
 				},
 			},
@@ -92,7 +92,7 @@ func TestEmptyState(t *testing.T) {
 				},
 				Deploy: &proto.DeployMetadata{
 					Cluster:   proto.ClusterType_GKE,
-					Deployers: []*proto.DeployMetadata_Deployer{{Type: proto.DeployerType_KUSTOMIZE, Count: 1}}},
+					Deployers: []*proto.DeployMetadata_Deployer{{Type: proto.DeployerType_KUBECTL, Count: 1}}},
 			},
 		},
 		{
@@ -116,11 +116,11 @@ func TestEmptyState(t *testing.T) {
 			},
 		},
 		{
-			description: "no build, kustomize deployer other cluster",
+			description: "no build, kubectl deployer other cluster",
 			cfg: latest.Pipeline{
 				Deploy: latest.DeployConfig{
 					DeployType: latest.DeployType{
-						KustomizeDeploy: &latest.KustomizeDeploy{},
+						KubectlDeploy: &latest.KubectlDeploy{},
 					},
 				},
 			},
@@ -129,7 +129,7 @@ func TestEmptyState(t *testing.T) {
 				Build: &proto.BuildMetadata{},
 				Deploy: &proto.DeployMetadata{
 					Cluster:   proto.ClusterType_OTHER,
-					Deployers: []*proto.DeployMetadata_Deployer{{Type: proto.DeployerType_KUSTOMIZE, Count: 1}},
+					Deployers: []*proto.DeployMetadata_Deployer{{Type: proto.DeployerType_KUBECTL, Count: 1}},
 				},
 			},
 		},
