@@ -20,15 +20,19 @@ import (
 	"context"
 	"fmt"
 	"os"
+	"path/filepath"
 	"strings"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 )
 
+var ManifestsFromGCS = "manifests_from_gcs"
+
 // DownloadFromGCS downloads all provided manifests from a remote GCS bucket,
 // and returns a relative path pointing to the GCS temp dir.
 func DownloadFromGCS(manifests []string) (string, error) {
-	if err := os.MkdirAll(ManifestTmpDir, os.ModePerm); err != nil {
+	dir := filepath.Join(ManifestTmpDir, ManifestsFromGCS)
+	if err := os.MkdirAll(dir, os.ModePerm); err != nil {
 		return "", fmt.Errorf("failed to create the tmp directory: %w", err)
 	}
 	for _, manifest := range manifests {
@@ -36,7 +40,7 @@ func DownloadFromGCS(manifests []string) (string, error) {
 			return "", fmt.Errorf("%v is not a valid GCS path", manifest)
 		}
 		gcs := util.Gsutil{}
-		if err := gcs.Copy(context.Background(), manifest, ManifestTmpDir, true); err != nil {
+		if err := gcs.Copy(context.Background(), manifest, dir, true); err != nil {
 			return "", fmt.Errorf("failed to download manifests fom GCS: %w", err)
 		}
 	}
