@@ -20,20 +20,25 @@ import (
 	"context"
 	"fmt"
 	"os"
+	"os/exec"
+	"strings"
 
 	"github.com/google/uuid"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/config"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
 	kubectx "github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/context"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output/log"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	schemaUtil "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/util"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 )
 
 type RunContext struct {
 	Opts               config.SkaffoldOptions
 	Pipelines          Pipelines
 	KubeContext        string
+	Namespaces         []string
 	WorkingDir         string
 	InsecureRegistries map[string]bool
 	Cluster            config.Cluster
@@ -43,6 +48,7 @@ type RunContext struct {
 // Pipelines encapsulates multiple config pipelines
 type Pipelines struct {
 	pipelines            []latest.Pipeline
+	pipelinesByConfig    map[string]latest.Pipeline
 	pipelinesByImageName map[string]latest.Pipeline
 }
 
@@ -51,6 +57,10 @@ func (ps Pipelines) All() []latest.Pipeline {
 	return ps.pipelines
 }
 
+func (ps Pipelines) AllByConfigNames() map[string]latest.Pipeline {
+	return ps.pipelinesByConfig
+}
+
 // Head returns the first `latest.Pipeline`.
 func (ps Pipelines) Head() latest.Pipeline {
 	return ps.pipelines[0] // there always exists atleast one pipeline.
@@ -83,6 +93,7 @@ func (ps Pipelines) Artifacts() []*latest.Artifact {
 	return artifacts
 }
 
+// TODO: Clean up code duplication
 func (ps Pipelines) DeployConfigs() []latest.DeployConfig {
 	var cfgs []latest.DeployConfig
 	for _, p := range ps.pipelines {
@@ -99,6 +110,14 @@ func (ps Pipelines) Deployers() []latest.DeployConfig {
 	return deployers
 }
 
+func (ps Pipelines) Renderers() []latest.RenderConfig {
+	var rcs []latest.RenderConfig
+	for _, p := range ps.pipelines {
+		rcs = append(rcs, p.Render)
+	}
+	return rcs
+}
+
 func (ps Pipelines) TestCases() []*latest.TestCase {
 	var tests []*latest.TestCase
 	for _, p := range ps.pipelines {
@@ -139,14 +158,18 @@ func (ps Pipelines) StatusCheckDeadlineSeconds() int {
 	}
 	return c
 }
-func NewPipelines(pipelines []latest.Pipeline) Pipelines {
+func NewPipelines(pipelinesByConfig map[string]latest.Pipeline) Pipelines {
 	m := make(map[string]latest.Pipeline)
-	for _, p := range pipelines {
+	var pipelines []latest.Pipeline
+
+	for _, p := range pipelinesByConfig {
 		for _, a := range p.Build.Artifacts {
 			m[a.ImageName] = p
 		}
+		pipelines = append(pipelines, p)
 	}
-	return Pipelines{pipelines: pipelines, pipelinesByImageName: m}
+
+	return Pipelines{pipelines: pipelines, pipelinesByImageName: m, pipelinesByConfig: pipelinesByConfig}
 }
 
 func (rc *RunContext) PipelineForImage(imageName string) (latest.Pipeline, bool) {
@@ -163,6 +186,8 @@ func (rc *RunContext) DeployConfigs() []latest.DeployConfig { return rc.Pipeline
 
 func (rc *RunContext) Deployers() []latest.DeployConfig { return rc.Pipelines.Deployers() }
 
+func (rc *RunContext) Renderers() []latest.RenderConfig { return rc.Pipelines.Renderers() }
+
 func (rc *RunContext) TestCases() []*latest.TestCase { return rc.Pipelines.TestCases() }
 
 func (rc *RunContext) StatusCheckDeadlineSeconds() int {
@@ -191,14 +216,36 @@ func (rc *RunContext) AddSkaffoldLabels() bool {
 	return rc.Opts.Mode() != config.RunModes.Render
 }
 
-func (rc *RunContext) DefaultPipeline() latest.Pipeline              { return rc.Pipelines.Head() }
-func (rc *RunContext) GetKubeContext() string                        { return rc.KubeContext }
-func (rc *RunContext) GetPipelines() []latest.Pipeline               { return rc.Pipelines.All() }
-func (rc *RunContext) GetInsecureRegistries() map[string]bool        { return rc.InsecureRegistries }
-func (rc *RunContext) GetWorkingDir() string                         { return rc.WorkingDir }
-func (rc *RunContext) GetCluster() config.Cluster                    { return rc.Cluster }
-func (rc *RunContext) GetNamespace() string                          { return rc.Opts.Namespace }
+func (rc *RunContext) UsingLegacyHelmDeploy() bool {
+	for _, config := range rc.DeployConfigs() {
+		if config.LegacyHelmDeploy != nil {
+			return true
+		}
+	}
+
+	return false
+}
+
+func (rc *RunContext) DefaultPipeline() latest.Pipeline       { return rc.Pipelines.Head() }
+func (rc *RunContext) GetKubeContext() string                 { return rc.KubeContext }
+func (rc *RunContext) GetNamespaces() []string                { return rc.Namespaces }
+func (rc *RunContext) GetPipelines() []latest.Pipeline        { return rc.Pipelines.All() }
+func (rc *RunContext) GetInsecureRegistries() map[string]bool { return rc.InsecureRegistries }
+func (rc *RunContext) GetWorkingDir() string                  { return rc.WorkingDir }
+func (rc *RunContext) GetCluster() config.Cluster             { return rc.Cluster }
+func (rc *RunContext) GetNamespace() string {
+	if rc.Opts.Namespace != "" {
+		return rc.Opts.Namespace
+	}
+	b, err := (&util.Commander{}).RunCmdOut(context.Background(), exec.Command("kubectl", "config", "view", "--minify", "-o", "jsonpath='{..namespace}'"))
+	if err != nil {
+		return rc.Opts.Namespace
+	}
+	return strings.Trim(string(b), "'")
+}
 func (rc *RunContext) AutoBuild() bool                               { return rc.Opts.AutoBuild }
+func (rc *RunContext) DisableMultiPlatformBuild() bool               { return rc.Opts.DisableMultiPlatformBuild }
+func (rc *RunContext) CheckClusterNodePlatforms() bool               { return rc.Opts.CheckClusterNodePlatforms }
 func (rc *RunContext) AutoDeploy() bool                              { return rc.Opts.AutoDeploy }
 func (rc *RunContext) AutoSync() bool                                { return rc.Opts.AutoSync }
 func (rc *RunContext) ContainerDebugging() bool                      { return rc.Opts.ContainerDebugging }
@@ -210,7 +257,6 @@ func (rc *RunContext) CustomTag() string                             { return rc
 func (rc *RunContext) DefaultRepo() *string                          { return rc.Cluster.DefaultRepo.Value() }
 func (rc *RunContext) MultiLevelRepo() *bool                         { return rc.Opts.MultiLevelRepo }
 func (rc *RunContext) Mode() config.RunMode                          { return rc.Opts.Mode() }
-func (rc *RunContext) DigestSource() string                          { return rc.Opts.DigestSource }
 func (rc *RunContext) DryRun() bool                                  { return rc.Opts.DryRun }
 func (rc *RunContext) ForceDeploy() bool                             { return rc.Opts.Force }
 func (rc *RunContext) GetKubeConfig() string                         { return rc.Opts.KubeConfig }
@@ -228,9 +274,9 @@ func (rc *RunContext) PortForwardOptions() config.PortForwardOptions { return rc
 func (rc *RunContext) Prune() bool                                   { return rc.Opts.Prune() }
 func (rc *RunContext) RenderOnly() bool                              { return rc.Opts.RenderOnly }
 func (rc *RunContext) RenderOutput() string                          { return rc.Opts.RenderOutput }
-func (rc *RunContext) SkipRender() bool                              { return rc.Opts.SkipRender }
 func (rc *RunContext) StatusCheck() *bool                            { return rc.Opts.StatusCheck.Value() }
 func (rc *RunContext) IterativeStatusCheck() bool                    { return rc.Opts.IterativeStatusCheck }
+func (rc *RunContext) FastFailStatusCheck() bool                     { return rc.Opts.FastFailStatusCheck }
 func (rc *RunContext) Tail() bool                                    { return rc.Opts.Tail }
 func (rc *RunContext) Trigger() string                               { return rc.Opts.Trigger }
 func (rc *RunContext) WaitForDeletions() config.WaitForDeletions     { return rc.Opts.WaitForDeletions }
@@ -243,15 +289,45 @@ func (rc *RunContext) RPCPort() *int                                 { return rc
 func (rc *RunContext) RPCHTTPPort() *int                             { return rc.Opts.RPCHTTPPort.Value() }
 func (rc *RunContext) PushImages() config.BoolOrUndefined            { return rc.Opts.PushImages }
 func (rc *RunContext) TransformRulesFile() string                    { return rc.Opts.TransformRulesFile }
+func (rc *RunContext) VerifyDockerNetwork() string                   { return rc.Opts.VerifyDockerNetwork }
 func (rc *RunContext) JSONParseConfig() latest.JSONParseConfig {
 	return rc.DefaultPipeline().Deploy.Logs.JSONParse
 }
+func (rc *RunContext) EnablePlatformNodeAffinityInRenderedManifests() bool {
+	return rc.Opts.EnablePlatformNodeAffinity && rc.Cluster.IsMixedPlatform
+}
+func (rc *RunContext) EnableGKEARMNodeTolerationInRenderedManifests() bool {
+	return rc.Opts.EnableGKEARMNodeToleration
+}
+
+func (rc *RunContext) DigestSource() string {
+	if rc.Opts.DigestSource != "" {
+		return rc.Opts.DigestSource
+	}
+	if rc.Cluster.Local {
+		return constants.TagDigestSource
+	}
+	return constants.RemoteDigestSource
+}
+
+func getConfigName(configName string) string {
+	pipelineConfigName := configName
+
+	if len(pipelineConfigName) == 0 {
+		configNameUUID, _ := uuid.NewUUID()
+		pipelineConfigName = configNameUUID.String()
+	}
+
+	return pipelineConfigName
+}
 
 func GetRunContext(ctx context.Context, opts config.SkaffoldOptions, configs []schemaUtil.VersionedConfig) (*RunContext, error) {
-	var pipelines []latest.Pipeline
+	pipelines := make(map[string]latest.Pipeline)
 	for _, cfg := range configs {
 		if cfg != nil {
-			pipelines = append(pipelines, cfg.(*latest.SkaffoldConfig).Pipeline)
+			pipeline := cfg.(*latest.SkaffoldConfig).Pipeline
+			cfgName := getConfigName(cfg.(*latest.SkaffoldConfig).Metadata.Name)
+			pipelines[cfgName] = pipeline
 		}
 	}
 	kubeConfig, err := kubectx.CurrentConfig()
