@@ -66,8 +66,8 @@ func TestDisplaySurveyForm(t *testing.T) {
 }
 
 func TestShouldDisplayPrompt(t *testing.T) {
-	tenDaysAgo := time.Now().AddDate(0, 0, -10).Format(time.RFC3339)
 	fiveDaysAgo := time.Now().AddDate(0, 0, -5).Format(time.RFC3339)
+	threeDaysAgo := time.Now().AddDate(0, 0, -3).Format(time.RFC3339)
 	// less than 90 days ago
 	twoMonthsAgo := time.Now().AddDate(0, -2, -5).Format(time.RFC3339)
 	// at least 90 days ago
@@ -82,16 +82,16 @@ func TestShouldDisplayPrompt(t *testing.T) {
 			description: "should not display prompt when prompt is disabled",
 			cfg: &sConfig.GlobalConfig{
 				Global: &sConfig.ContextConfig{
-					Survey: &sConfig.SurveyConfig{DisablePrompt: util.BoolPtr(true)},
+					Survey: &sConfig.SurveyConfig{DisablePrompt: util.Ptr(true)},
 				}},
 		},
 		{
-			description: "should not display prompt when last prompted is less than 2 weeks",
+			description: "should not display prompt when last prompted is less than 5 days",
 			cfg: &sConfig.GlobalConfig{
 				Global: &sConfig.ContextConfig{
 					Survey: &sConfig.SurveyConfig{
-						DisablePrompt: util.BoolPtr(false),
-						LastPrompted:  fiveDaysAgo,
+						DisablePrompt: util.Ptr(false),
+						LastPrompted:  threeDaysAgo,
 					}},
 			},
 		},
@@ -100,18 +100,18 @@ func TestShouldDisplayPrompt(t *testing.T) {
 			cfg: &sConfig.GlobalConfig{
 				Global: &sConfig.ContextConfig{
 					Survey: &sConfig.SurveyConfig{
-						DisablePrompt: util.BoolPtr(false),
+						DisablePrompt: util.Ptr(false),
 						LastTaken:     twoMonthsAgo,
 					}},
 			},
 		},
 		{
-			description: "should display prompt when last prompted is before 2 weeks",
+			description: "should display prompt when last prompted is before 5 days",
 			cfg: &sConfig.GlobalConfig{
 				Global: &sConfig.ContextConfig{
 					Survey: &sConfig.SurveyConfig{
-						DisablePrompt: util.BoolPtr(false),
-						LastPrompted:  tenDaysAgo,
+						DisablePrompt: util.Ptr(false),
+						LastPrompted:  fiveDaysAgo,
 					}},
 			},
 			expected: true,
@@ -121,7 +121,7 @@ func TestShouldDisplayPrompt(t *testing.T) {
 			cfg: &sConfig.GlobalConfig{
 				Global: &sConfig.ContextConfig{
 					Survey: &sConfig.SurveyConfig{
-						DisablePrompt: util.BoolPtr(false),
+						DisablePrompt: util.Ptr(false),
 						LastTaken:     threeMonthsAgo,
 					}},
 			},
@@ -132,7 +132,7 @@ func TestShouldDisplayPrompt(t *testing.T) {
 			cfg: &sConfig.GlobalConfig{
 				Global: &sConfig.ContextConfig{
 					Survey: &sConfig.SurveyConfig{
-						DisablePrompt: util.BoolPtr(false),
+						DisablePrompt: util.Ptr(false),
 						LastTaken:     twoMonthsAgo,
 						LastPrompted:  twoMonthsAgo,
 					}},
@@ -166,14 +166,14 @@ func TestIsSurveyPromptDisabled(t *testing.T) {
 		{
 			description: "config disable-prompt is true",
 			cfg: &sConfig.GlobalConfig{
-				Global: &sConfig.ContextConfig{Survey: &sConfig.SurveyConfig{DisablePrompt: util.BoolPtr(true)}},
+				Global: &sConfig.ContextConfig{Survey: &sConfig.SurveyConfig{DisablePrompt: util.Ptr(true)}},
 			},
 			expected: true,
 		},
 		{
 			description: "config disable-prompt is false",
 			cfg: &sConfig.GlobalConfig{
-				Global: &sConfig.ContextConfig{Survey: &sConfig.SurveyConfig{DisablePrompt: util.BoolPtr(false)}},
+				Global: &sConfig.ContextConfig{Survey: &sConfig.SurveyConfig{DisablePrompt: util.Ptr(false)}},
 			},
 		},
 		{
@@ -259,7 +259,7 @@ func TestRecentlyPromptedOrTaken(t *testing.T) {
 			cfg: &sConfig.GlobalConfig{
 				Global: &sConfig.ContextConfig{Survey: &sConfig.SurveyConfig{LastTaken: twoMonthsAgo,
 					UserSurveys: []*sConfig.UserSurvey{
-						{ID: "user", Taken: util.BoolPtr(true)},
+						{ID: "user", Taken: util.Ptr(true)},
 					}}}},
 			input: []config{hats, {id: "user", expiresAt: future,
 				isRelevantFn: func(_ []schemaUtil.VersionedConfig, _ sConfig.RunMode) bool {
@@ -273,7 +273,7 @@ func TestRecentlyPromptedOrTaken(t *testing.T) {
 			cfg: &sConfig.GlobalConfig{
 				Global: &sConfig.ContextConfig{Survey: &sConfig.SurveyConfig{
 					UserSurveys: []*sConfig.UserSurvey{
-						{ID: "user", Taken: util.BoolPtr(true)},
+						{ID: "user", Taken: util.Ptr(true)},
 					}}}},
 			input: []config{hats, {id: "user", expiresAt: future,
 				isRelevantFn: func(_ []schemaUtil.VersionedConfig, _ sConfig.RunMode) bool {
